==> tspart-0.1.0.tar.gz: tspart-0.1.0/README.md <==
<div align="center">
    <p><b>TSP Art</b></p>
    <p>TSP Art Module for Python</p>
    <a href="https://pypi.org/project/tspart/"><img src="https://img.shields.io/pypi/pyversions/tspart?logo=python&logoColor=white" alt="Python Version" /></a>
    <a href="https://pypi.org/project/tspart/"><img src="https://img.shields.io/pypi/v/tspart?logo=PyPI&logoColor=white" alt="PyPI Version" /></a>
    <br>
    <a href="https://github.com/nimaid/tspart/actions/workflows/master.yml"><img src="https://img.shields.io/github/actions/workflow/status/nimaid/tspart/master.yml?logo=GitHub" alt="GitHub Build" /></a>
    <a href="https://codecov.io/gh/nimaid/tspart"><img src="https://img.shields.io/codecov/c/github/nimaid/tspart?logo=codecov&logoColor=white" alt="Codecov Coverage" /></a>
    Codacy Badge
    <br>
    <a href="https://github.com/nimaid/tspart/raw/main/LICENSE"><img src="https://img.shields.io/pypi/l/tspart?logo=opensourceinitiative&logoColor=white" alt="License" /></a>
    <a href="https://pypi.org/project/tspart/"><img src="https://img.shields.io/pypi/dm/tspart.svg?label=pypi%20downloads&logo=PyPI&logoColor=white" alt="PyPI Downloads" /></a>
    <a href="https://paypal.me/EllaJameson"><img src="https://img.shields.io/badge/PayPal-donate?logo=paypal&logoColor=white&label=donate&color=purple" alt="Donate" /></a>
</div>

<p align="center"><img src="docs/example.jpg" width="800px" alt="Example image"/></p>

## Command Line Usage
```
usage: tspart [-h] -1 FIRST_ARG [-2 SECOND_ARG] [-o OPCODE]

A python 3 module.

Valid parameters are shown in {braces}
Default parameters are shown in [brackets].

options:
  -h, --help            show this help message and exit
  -1 FIRST_ARG, --first FIRST_ARG
                        the first argument
  -2 SECOND_ARG, --second SECOND_ARG
                        the second argument [1.0]
  -o OPCODE, --operation OPCODE
                        the operation to perform on the arguments, either {+, -, *, /} [+]
```

## Usage In Custom Code
TODO

# Full Documentation
<p align="center"><a href="https://tspart.readthedocs.io/en/latest/index.html"><img src="https://brand-guidelines.readthedocs.org/_images/logo-wordmark-vertical-dark.png" width="300px" alt="tspart on Read the Docs"></a></p>

==> tspart-0.1.1.tar.gz: tspart-0.1.1/README.md <==
<div align="center">
    <p><b>TSP Art</b></p>
    <p>TSP Art Module for Python</p>
    <a href="https://pypi.org/project/tspart/"><img src="https://img.shields.io/pypi/pyversions/tspart?logo=python&logoColor=white" alt="Python Version" /></a>
    <a href="https://pypi.org/project/tspart/"><img src="https://img.shields.io/pypi/v/tspart?logo=PyPI&logoColor=white" alt="PyPI Version" /></a>
    <br>
    <a href="https://github.com/nimaid/python-tspart/actions/workflows/publish-pypi-release.yml"><img src="https://img.shields.io/github/actions/workflow/status/nimaid/python-tspart/publish-pypi-release.yml?logo=GitHub" alt="GitHub Build" /></a>
    <a href="https://codecov.io/gh/nimaid/tspart"><img src="https://img.shields.io/codecov/c/github/nimaid/tspart?logo=codecov&logoColor=white" alt="Codecov Coverage" /></a>
    <a href="https://app.codacy.com/gh/nimaid/python-tspart/dashboard"><img src="https://app.codacy.com/project/badge/Grade/3b5186afcd5940fcab787150d374e1c8" alt="Codacy Badge" /></a>
    <br>
    <a href="https://github.com/nimaid/tspart/raw/main/LICENSE"><img src="https://img.shields.io/pypi/l/tspart?logo=opensourceinitiative&logoColor=white" alt="License" /></a>
    <a href="https://pypi.org/project/tspart/"><img src="https://img.shields.io/pypi/dm/tspart.svg?label=pypi%20downloads&logo=PyPI&logoColor=white" alt="PyPI Downloads" /></a>
    <a href="https://paypal.me/EllaJameson"><img src="https://img.shields.io/badge/PayPal-donate?logo=paypal&logoColor=white&label=donate&color=purple" alt="Donate" /></a>
</div>

<p align="center"><img src="docs/example.png" width="800px" alt="Example image"/></p>

## Command Line Usage
```
usage: tspart [-h] -1 FIRST_ARG [-2 SECOND_ARG] [-o OPCODE]

A python 3 module.

Valid parameters are shown in {braces}
Default parameters are shown in [brackets].

options:
  -h, --help            show this help message and exit
  -1 FIRST_ARG, --first FIRST_ARG
                        the first argument
  -2 SECOND_ARG, --second SECOND_ARG
                        the second argument [1.0]
  -o OPCODE, --operation OPCODE
                        the operation to perform on the arguments, either {+, -, *, /} [+]
```

## Usage In Custom Code
TODO

# Full Documentation
<p align="center"><a href="https://tspart.readthedocs.io/en/latest/index.html"><img src="https://brand-guidelines.readthedocs.org/_images/logo-wordmark-vertical-dark.png" width="300px" alt="tspart on Read the Docs"></a></p>
